start

# PO Files

PO files use the file format of the Gettext tools. See http://www.gnu.org/software/gettext/

For information on KDE style PO files, see http://public.planetmirror.com/pub/kde/devel/gettext-kde/

## Supported Features

- Headers
- Plural forms and plural form handling
- Obsolete messages
- Message Context (msgctxt)
- Language header (since gettext version 0.17)
- Previous message ID and context (#| msgid and #| msgctxt)

## Supported comments

- normal comments

      # this is another comment

- automatic comments

      #. comment extracted from the source code

- source location comments

      #: sourcefile.xxx:35

- typecomments

      #, fuzzy

- msgidcomments

      magid "_: within msgid\n"

  Also know as KDE style comments as they are used by KDE for message disambiguation and comments to translators. (support for this is being phased out)

- obsolete messages

      #~ msgid "Blah"
      #~ msgstr "Bleeh"

- previous msgid and msgctxt

       #| msgid "previous message"

## Unsupported Features

### Alternate language

    msgid "English"
    msgid[af] "Engels"

(This was proposed but not yet accepted in a released version of Gettext.)